@@ -46,9 +46,12 @@ def export_job(args):
     global logger
     logger = settings.get_logger()
     type = 'target'
+    params = '&all_judgements=false'
     if args.raw:
         type='raw'
-    url = f'/jobs/{args.job_id}/download/?export_type={type}&all_judgements=false'
+    elif args.worker_data:
+        params = '&all_judgements=true&include_worker_data=true'
+    url = f'/jobs/{args.job_id}/download/?export_type={type}{params}'
     r = make_request(url)
     data = r.json()
     print(data)
