@@ -9,7 +9,7 @@ def make_request(url, post_data={}, files={}, headers={}, json={}):
     global logger
     if not logger:
         logger = settings.get_logger()
-    logger.info(f'request {url=} {headers=} {post_data=} {json=}')
+    logger.info(f'request url={url} headers={headers} post_data={post_data} json={json}')
     full_url = SERVER + url
     headers = headers.copy()
     headers['Authorization'] = f'BEARER {TOKEN}'
